@@ -490,6 +490,7 @@ BEGIN
     SELECT RAISE(ABORT, 'insert on conversion violates constraint: method should be known')
         WHERE (NEW.auth_name || '_' || NEW.code || '_' || NEW.name) NOT IN (
             'EPSG_1024_Popular Visualisation Pseudo Mercator',
+            'EPSG_1026_Mercator (Spherical)',
             'EPSG_1027_Lambert Azimuthal Equal Area (Spherical)',
             'EPSG_1028_Equidistant Cylindrical',
             'EPSG_1029_Equidistant Cylindrical (Spherical)',
@@ -504,6 +505,7 @@ BEGIN
             'EPSG_1078_Equal Earth',
             'EPSG_1102_Lambert Conic Conformal (1SP variant B)',
             'EPSG_1111_Transverse Mercator 3D',
+            'EPSG_1119_Equidistant Conic',
             'EPSG_9602_Geographic/geocentric conversions',
             'EPSG_9659_Geographic3D to 2D conversion',
             'EPSG_9801_Lambert Conic Conformal (1SP)',
