@@ -1,4 +1,4 @@
-#define PJ_LIB__
+#define PJ_LIB_
 
 #include "proj_internal.h"
 #include <errno.h>
@@ -19,9 +19,9 @@ struct Set {
 };
 } // anonymous namespace
 
-static PJ_COORD set_fwd_inv(PJ_COORD point, PJ *P) {
+static void set_fwd_inv(PJ_COORD &point, PJ *P) {
 
-    struct Set *set = static_cast<struct Set*>(P->opaque);
+    struct Set *set = static_cast<struct Set *>(P->opaque);
 
     if (set->v1)
         point.v[0] = set->v1_val;
@@ -31,44 +31,38 @@ static PJ_COORD set_fwd_inv(PJ_COORD point, PJ *P) {
         point.v[2] = set->v3_val;
     if (set->v4)
         point.v[3] = set->v4_val;
-
-    return point;
 }
 
 PJ *OPERATION(set, 0) {
     P->inv4d = set_fwd_inv;
     P->fwd4d = set_fwd_inv;
 
-    auto set = static_cast<struct Set*>(calloc (1, sizeof(struct Set)));
+    auto set = static_cast<struct Set *>(calloc(1, sizeof(struct Set)));
     P->opaque = set;
-    if (nullptr==P->opaque)
+    if (nullptr == P->opaque)
         return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
 
-    if (pj_param_exists(P->params, "v_1"))
-    {
+    if (pj_param_exists(P->params, "v_1")) {
         set->v1 = true;
-        set->v1_val = pj_param (P->ctx, P->params, "dv_1").f;
+        set->v1_val = pj_param(P->ctx, P->params, "dv_1").f;
     }
 
-    if (pj_param_exists(P->params, "v_2"))
-    {
+    if (pj_param_exists(P->params, "v_2")) {
         set->v2 = true;
-        set->v2_val = pj_param (P->ctx, P->params, "dv_2").f;
+        set->v2_val = pj_param(P->ctx, P->params, "dv_2").f;
     }
 
-    if (pj_param_exists(P->params, "v_3"))
-    {
+    if (pj_param_exists(P->params, "v_3")) {
         set->v3 = true;
-        set->v3_val = pj_param (P->ctx, P->params, "dv_3").f;
+        set->v3_val = pj_param(P->ctx, P->params, "dv_3").f;
     }
 
-    if (pj_param_exists(P->params, "v_4"))
-    {
+    if (pj_param_exists(P->params, "v_4")) {
         set->v4 = true;
-        set->v4_val = pj_param (P->ctx, P->params, "dv_4").f;
+        set->v4_val = pj_param(P->ctx, P->params, "dv_4").f;
     }
 
-    P->left  = PJ_IO_UNITS_WHATEVER;
+    P->left = PJ_IO_UNITS_WHATEVER;
     P->right = PJ_IO_UNITS_WHATEVER;
 
     return P;
