@@ -1,4 +1,4 @@
-#define PJ_LIB__
+#define PJ_LIB_
 
 #include <math.h>
 
@@ -7,27 +7,26 @@
 
 PROJ_HEAD(eck2, "Eckert II") "\n\tPCyl, Sph";
 
-#define FXC     0.46065886596178063902
-#define FYC     1.44720250911653531871
-#define C13     0.33333333333333333333
-#define ONEEPS  1.0000001
+#define FXC 0.46065886596178063902
+#define FYC 1.44720250911653531871
+#define C13 0.33333333333333333333
+#define ONEEPS 1.0000001
 
-
-static PJ_XY eck2_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward */
-    PJ_XY xy = {0.0,0.0};
-    (void) P;
+static PJ_XY eck2_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
+    PJ_XY xy = {0.0, 0.0};
+    (void)P;
 
     xy.x = FXC * lp.lam * (xy.y = sqrt(4. - 3. * sin(fabs(lp.phi))));
     xy.y = FYC * (2. - xy.y);
-    if ( lp.phi < 0.) xy.y = -xy.y;
+    if (lp.phi < 0.)
+        xy.y = -xy.y;
 
     return (xy);
 }
 
-
-static PJ_LP eck2_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse */
-    PJ_LP lp = {0.0,0.0};
-    (void) P;
+static PJ_LP eck2_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
+    PJ_LP lp = {0.0, 0.0};
+    (void)P;
 
     lp.phi = 2. - fabs(xy.y) / FYC;
     lp.lam = xy.x / (FXC * lp.phi);
@@ -46,8 +45,6 @@ static PJ_LP eck2_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse
     return (lp);
 }
 
-
-
 PJ *PROJECTION(eck2) {
     P->es = 0.;
     P->inv = eck2_s_inverse;
