@@ -1,18 +1,13 @@
-#define PJ_LIB__
-#include <errno.h>
+#define PJ_LIB_
 #include "proj.h"
 #include "proj_internal.h"
+#include <errno.h>
 #include <math.h>
 
 PROJ_HEAD(laea, "Lambert Azimuthal Equal Area") "\n\tAzi, Sph&Ell";
 
 namespace { // anonymous namespace
-enum Mode {
-    N_POLE = 0,
-    S_POLE = 1,
-    EQUIT  = 2,
-    OBLIQ  = 3
-};
+enum Mode { N_POLE = 0, S_POLE = 1, EQUIT = 2, OBLIQ = 3 };
 } // anonymous namespace
 
 namespace { // anonymous namespace
@@ -30,12 +25,12 @@ struct pj_opaque {
 };
 } // anonymous namespace
 
-#define EPS10   1.e-10
+#define EPS10 1.e-10
 
-static PJ_XY laea_e_forward (PJ_LP lp, PJ *P) {          /* Ellipsoidal, forward */
-    PJ_XY xy = {0.0,0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
-    double coslam, sinlam, sinphi, q, sinb=0.0, cosb=0.0, b=0.0;
+static PJ_XY laea_e_forward(PJ_LP lp, PJ *P) { /* Ellipsoidal, forward */
+    PJ_XY xy = {0.0, 0.0};
+    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    double coslam, sinlam, sinphi, q, sinb = 0.0, cosb = 0.0, b = 0.0;
 
     coslam = cos(lp.lam);
     sinlam = sin(lp.lam);
@@ -78,7 +73,7 @@ static PJ_XY laea_e_forward (PJ_LP lp, PJ *P) {          /* Ellipsoidal, forward
     case EQUIT:
         b = sqrt(2. / (1. + cosb * coslam));
         xy.y = b * sinb * Q->ymf;
-eqcon:
+    eqcon:
         xy.x = Q->xmf * b * cosb * sinlam;
         break;
     case N_POLE:
@@ -94,11 +89,10 @@ eqcon:
     return xy;
 }
 
-
-static PJ_XY laea_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward */
-    PJ_XY xy = {0.0,0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
-    double  coslam, cosphi, sinphi;
+static PJ_XY laea_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
+    PJ_XY xy = {0.0, 0.0};
+    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    double coslam, cosphi, sinphi;
 
     sinphi = sin(lp.phi);
     cosphi = cos(lp.phi);
@@ -109,19 +103,20 @@ static PJ_XY laea_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward
         goto oblcon;
     case OBLIQ:
         xy.y = 1. + Q->sinb1 * sinphi + Q->cosb1 * cosphi * coslam;
-oblcon:
+    oblcon:
         if (xy.y <= EPS10) {
             proj_errno_set(P, PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN);
             return xy;
         }
         xy.y = sqrt(2. / xy.y);
         xy.x = xy.y * cosphi * sin(lp.lam);
-        xy.y *= Q->mode == EQUIT ? sinphi :
-           Q->cosb1 * sinphi - Q->sinb1 * cosphi * coslam;
+        xy.y *= Q->mode == EQUIT
+                    ? sinphi
+                    : Q->cosb1 * sinphi - Q->sinb1 * cosphi * coslam;
         break;
     case N_POLE:
         coslam = -coslam;
-        /*-fallthrough*/
+        PROJ_FALLTHROUGH;
     case S_POLE:
         if (fabs(lp.phi + P->phi0) < EPS10) {
             proj_errno_set(P, PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN);
@@ -136,18 +131,16 @@ oblcon:
     return xy;
 }
 
-
-static PJ_LP laea_e_inverse (PJ_XY xy, PJ *P) {          /* Ellipsoidal, inverse */
-    PJ_LP lp = {0.0,0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
-    double cCe, sCe, q, rho, ab=0.0;
+static PJ_LP laea_e_inverse(PJ_XY xy, PJ *P) { /* Ellipsoidal, inverse */
+    PJ_LP lp = {0.0, 0.0};
+    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    double cCe, sCe, q, rho, ab = 0.0;
 
     switch (Q->mode) {
     case EQUIT:
-    case OBLIQ:
-    {
+    case OBLIQ: {
         xy.x /= Q->dd;
-        xy.y *=  Q->dd;
+        xy.y *= Q->dd;
         rho = hypot(xy.x, xy.y);
         if (rho < EPS10) {
             lp.lam = 0.;
@@ -155,8 +148,7 @@ static PJ_LP laea_e_inverse (PJ_XY xy, PJ *P) {          /* Ellipsoidal, inverse
             return lp;
         }
         const double asin_argument = .5 * rho / Q->rq;
-        if( asin_argument > 1 )
-        {
+        if (asin_argument > 1) {
             proj_errno_set(P, PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN);
             return lp;
         }
@@ -175,7 +167,7 @@ static PJ_LP laea_e_inverse (PJ_XY xy, PJ *P) {          /* Ellipsoidal, inverse
     }
     case N_POLE:
         xy.y = -xy.y;
-        /*-fallthrough*/
+        PROJ_FALLTHROUGH;
     case S_POLE:
         q = (xy.x * xy.x + xy.y * xy.y);
         if (q == 0.0) {
@@ -185,7 +177,7 @@ static PJ_LP laea_e_inverse (PJ_XY xy, PJ *P) {          /* Ellipsoidal, inverse
         }
         ab = 1. - q / Q->qp;
         if (Q->mode == S_POLE)
-            ab = - ab;
+            ab = -ab;
         break;
     }
     lp.lam = atan2(xy.x, xy.y);
@@ -193,14 +185,13 @@ static PJ_LP laea_e_inverse (PJ_XY xy, PJ *P) {          /* Ellipsoidal, inverse
     return lp;
 }
 
-
-static PJ_LP laea_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse */
-    PJ_LP lp = {0.0,0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
-    double  cosz=0.0, rh, sinz=0.0;
+static PJ_LP laea_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
+    PJ_LP lp = {0.0, 0.0};
+    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    double cosz = 0.0, rh, sinz = 0.0;
 
     rh = hypot(xy.x, xy.y);
-    if ((lp.phi = rh * .5 ) > 1.) {
+    if ((lp.phi = rh * .5) > 1.) {
         proj_errno_set(P, PROJ_ERR_COORD_TRANSFM_OUTSIDE_PROJECTION_DOMAIN);
         return lp;
     }
@@ -216,8 +207,9 @@ static PJ_LP laea_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse
         xy.y = cosz * rh;
         break;
     case OBLIQ:
-        lp.phi = fabs(rh) <= EPS10 ? P->phi0 :
-           asin(cosz * Q->sinb1 + xy.y * sinz * Q->cosb1 / rh);
+        lp.phi = fabs(rh) <= EPS10
+                     ? P->phi0
+                     : asin(cosz * Q->sinb1 + xy.y * sinz * Q->cosb1 / rh);
         xy.x *= sinz * Q->cosb1;
         xy.y = (cosz - sin(lp.phi) * Q->sinb1) * rh;
         break;
@@ -229,36 +221,37 @@ static PJ_LP laea_s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse
         lp.phi -= M_HALFPI;
         break;
     }
-    lp.lam = (xy.y == 0. && (Q->mode == EQUIT || Q->mode == OBLIQ)) ?
-        0. : atan2(xy.x, xy.y);
+    lp.lam = (xy.y == 0. && (Q->mode == EQUIT || Q->mode == OBLIQ))
+                 ? 0.
+                 : atan2(xy.x, xy.y);
     return (lp);
 }
 
-
-static PJ *destructor (PJ *P, int errlev) {
-    if (nullptr==P)
+static PJ *destructor(PJ *P, int errlev) {
+    if (nullptr == P)
         return nullptr;
 
-    if (nullptr==P->opaque)
-        return pj_default_destructor (P, errlev);
+    if (nullptr == P->opaque)
+        return pj_default_destructor(P, errlev);
 
-    free (static_cast<struct pj_opaque*>(P->opaque)->apa);
+    free(static_cast<struct pj_opaque *>(P->opaque)->apa);
 
     return pj_default_destructor(P, errlev);
 }
 
-
 PJ *PROJECTION(laea) {
     double t;
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(calloc (1, sizeof (struct pj_opaque)));
-    if (nullptr==Q)
-        return pj_default_destructor (P, PROJ_ERR_OTHER /*ENOMEM*/);
+    struct pj_opaque *Q =
+        static_cast<struct pj_opaque *>(calloc(1, sizeof(struct pj_opaque)));
+    if (nullptr == Q)
+        return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     P->opaque = Q;
     P->destructor = destructor;
 
     t = fabs(P->phi0);
-    if (t > M_HALFPI + EPS10 ) {
-        proj_log_error(P, _("Invalid value for lat_0: |lat_0| should be <= 90°"));
+    if (t > M_HALFPI + EPS10) {
+        proj_log_error(P,
+                       _("Invalid value for lat_0: |lat_0| should be <= 90°"));
         return destructor(P, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
     }
     if (fabs(t - M_HALFPI) < EPS10)
@@ -274,7 +267,7 @@ PJ *PROJECTION(laea) {
         Q->qp = pj_qsfn(1., P->e, P->one_es);
         Q->mmf = .5 / (1. - P->es);
         Q->apa = pj_authset(P->es);
-        if (nullptr==Q->apa)
+        if (nullptr == Q->apa)
             return destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
         switch (Q->mode) {
         case N_POLE:
@@ -291,8 +284,8 @@ PJ *PROJECTION(laea) {
             sinphi = sin(P->phi0);
             Q->sinb1 = pj_qsfn(sinphi, P->e, P->one_es) / Q->qp;
             Q->cosb1 = sqrt(1. - Q->sinb1 * Q->sinb1);
-            Q->dd = cos(P->phi0) / (sqrt(1. - P->es * sinphi * sinphi) *
-               Q->rq * Q->cosb1);
+            Q->dd = cos(P->phi0) /
+                    (sqrt(1. - P->es * sinphi * sinphi) * Q->rq * Q->cosb1);
             Q->ymf = (Q->xmf = Q->rq) / Q->dd;
             Q->xmf *= Q->dd;
             break;
@@ -310,4 +303,3 @@ PJ *PROJECTION(laea) {
 
     return P;
 }
-
