@@ -1,4 +1,4 @@
-#define PJ_LIB__
+#define PJ_LIB_
 
 #include <math.h>
 
@@ -7,9 +7,9 @@
 
 PROJ_HEAD(mill, "Miller Cylindrical") "\n\tCyl, Sph";
 
-static PJ_XY s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward */
-    PJ_XY xy = {0.0,0.0};
-    (void) P;
+static PJ_XY mill_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
+    PJ_XY xy = {0.0, 0.0};
+    (void)P;
 
     xy.x = lp.lam;
     xy.y = log(tan(M_FORTPI + lp.phi * .4)) * 1.25;
@@ -17,10 +17,9 @@ static PJ_XY s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward */
     return (xy);
 }
 
-
-static PJ_LP s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse */
-    PJ_LP lp = {0.0,0.0};
-    (void) P;
+static PJ_LP mill_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
+    PJ_LP lp = {0.0, 0.0};
+    (void)P;
 
     lp.lam = xy.x;
     lp.phi = 2.5 * (atan(exp(.8 * xy.y)) - M_FORTPI);
@@ -28,11 +27,10 @@ static PJ_LP s_inverse (PJ_XY xy, PJ *P) {           /* Spheroidal, inverse */
     return (lp);
 }
 
-
 PJ *PROJECTION(mill) {
     P->es = 0.;
-    P->inv = s_inverse;
-    P->fwd = s_forward;
+    P->inv = mill_s_inverse;
+    P->fwd = mill_s_forward;
 
     return P;
 }
