@@ -1,4 +1,4 @@
-#define PJ_LIB__
+#define PJ_LIB_
 
 #include <errno.h>
 #include <math.h>
@@ -8,21 +8,21 @@
 
 namespace { // anonymous namespace
 struct pj_opaque {
-    double  phi1;
-    double  fxa;
-    double  fxb;
-    int     mode;
+    double phi1;
+    double fxa;
+    double fxb;
+    int mode;
 };
 } // anonymous namespace
 
 PROJ_HEAD(rpoly, "Rectangular Polyconic")
-    "\n\tConic, Sph, no inv\n\tlat_ts=";
+"\n\tConic, Sph, no inv\n\tlat_ts=";
 
 #define EPS 1e-9
 
-static PJ_XY rpoly_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forward */
-    PJ_XY xy = {0.0,0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(P->opaque);
+static PJ_XY rpoly_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
+    PJ_XY xy = {0.0, 0.0};
+    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
     double fa;
 
     if (Q->mode)
@@ -31,7 +31,7 @@ static PJ_XY rpoly_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forwar
         fa = 0.5 * lp.lam;
     if (fabs(lp.phi) < EPS) {
         xy.x = fa + fa;
-        xy.y = - P->phi0;
+        xy.y = -P->phi0;
     } else {
         xy.y = 1. / tan(lp.phi);
         fa = 2. * atan(fa * sin(lp.phi));
@@ -41,12 +41,11 @@ static PJ_XY rpoly_s_forward (PJ_LP lp, PJ *P) {           /* Spheroidal, forwar
     return xy;
 }
 
-
-
 PJ *PROJECTION(rpoly) {
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(pj_calloc (1, sizeof (struct pj_opaque)));
-    if (nullptr==Q)
-        return pj_default_destructor(P, ENOMEM);
+    struct pj_opaque *Q =
+        static_cast<struct pj_opaque *>(calloc(1, sizeof(struct pj_opaque)));
+    if (nullptr == Q)
+        return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     P->opaque = Q;
 
     Q->phi1 = fabs(pj_param(P->ctx, P->params, "rlat_ts").f);
